####Below are known sources of data that need to be added to the catalog. 

Donated datasets:
* None to add at this time.

Multiple SN datasets on VizieR:
* http://vizier.cfa.harvard.edu/viz-bin/VizieR?-source=J/ApJ/756/173 (Data in text files attached to catalog)
* http://vizier.cfa.harvard.edu/viz-bin/VizieR?-source=J/other/NewA/20.30/sources (Data in text files attached to catalog)

Single SN dataset on VizieR:
* SN2002cv - http://vizier.cfa.harvard.edu/viz-bin/VizieR-3?-source=J/MNRAS/384/107 (Use dust-corrected or not?)

Other multiple SN datasets:
* http://adsabs.harvard.edu/abs/1938ApJ....88..285B (Historical SN data)
* http://adsabs.harvard.edu/abs/1999AJ....117..725F (1979C, 1980K)
* http://iopscience.iop.org/article/10.1088/0004-637X/743/2/114/meta (PS1-10awh, PS1-10ky)
* http://mnras.oxfordjournals.org/content/452/4/3869.full (24 SLSNe) [Erratum: http://mnras.oxfordjournals.org/content/457/3/2514.full]
* http://mnras.oxfordjournals.org/content/444/3/2096.full (LSQ12dlf, SSS120810, SN2013dg)
* http://adsabs.harvard.edu/abs/2014arXiv1401.3317S (SDSS SNe light curves, broken link - http://sdssdp62.fnal.gov/sdsssn/DataRelease/index.html)
* http://mnras.oxfordjournals.org/content/446/4/3895 (18 Ia SNe, but counts not magnitudes)
* http://arxiv.org/abs/1603.03823
* http://arxiv.org/abs/1603.05657 (KSN2011a, KSN2011d)
* http://thesis.library.caltech.edu/6395/1/Kasliwal_PhD_Thesis.pdf
* http://arxiv.org/abs/1603.08953
* http://adsabs.harvard.edu/abs/2014A%26A...568A..19C (SN2013ez, SN2013fu)
* http://adsabs.harvard.edu/abs/1997AJ....114.2054A (SN 1995al, 1997Y, 1997bp)
* http://adsabs.harvard.edu/abs/2012A%26A...545L...7T (SN 2006V, 2006au)
* http://adsabs.harvard.edu/abs/1979AcC.....8....5F (Lists references for many historical LCs)
* http://adsabs.harvard.edu/abs/2006ApJ...645..841N (SNLS LCs)
* http://adsabs.harvard.edu/abs/2016arXiv160105955F (Late-time Iax spectra)
* http://adsabs.harvard.edu/abs/2016ApJ...819...35A (rapid risers)
* http://adsabs.harvard.edu/abs/2015arXiv151201303C (radio upper limits for Ibc SNe)

Other single SN datasets:
* SN1885A - 2011ApJ...730...89P (from Perets e-mail)
* SN1978K - http://adsabs.harvard.edu/abs/1993ApJ...416..167R (Table 1)
* SN1979C - http://adsabs.harvard.edu/abs/1981ApJ...244..780B
* SN1983V - http://adsabs.harvard.edu/abs/1997ApJ...483..675C
* SN1986G - http://adsabs.harvard.edu/abs/2002AJ....124..417H, May 7th spectrum
* SN1987A - http://adsabs.harvard.edu/abs/1996ApJ...467..435W
* SN1989B - http://adsabs.harvard.edu/abs/1990A%26A...237...79B (need to reacquire a few from original source)
* SN1991D - http://adsabs.harvard.edu/abs/2002MNRAS.336...91B
* SN1991T - http://adsabs.harvard.edu/abs/1996MNRAS.281..263M
* SN1992ar - http://adsabs.harvard.edu/abs/2000ApJ...529..661C
* SN1993J - http://adsabs.harvard.edu/abs/2000AJ....120.1487M
* SN1993J - http://adsabs.harvard.edu/abs/2000AJ....120.1499M
* SN1994D - http://adsabs.harvard.edu/abs/1996MNRAS.281..263M
* SN1994D - http://adsabs.harvard.edu/abs/1998AJ....115.1096G, June 5th spectrum
* SN1995D - http://adsabs.harvard.edu/abs/1996PASJ...48...51S
* SN1995N - http://adsabs.harvard.edu/abs/2002ApJ...572..350F
* SN1995V - http://adsabs.harvard.edu/abs/1998MNRAS.299..150F
* SN1996N - http://adsabs.harvard.edu/abs/1998A%26A...337..207S
* SN1996cb - http://adsabs.harvard.edu/abs/1999AJ....117..736Q
* SN1997X - http://adsabs.harvard.edu/abs/1998A%26A...333..159M
* SN1997ab - http://adsabs.harvard.edu/abs/2000MmSAI..71..317S
* SN1997eg - http://adsabs.harvard.edu/abs/2002MNRAS.330..844S
* SN1998bu - http://adsabs.harvard.edu/abs/2001ApJ...549L.215C (need to reacquire spectrum on 1999-01-23)
* SN1999E - http://adsabs.harvard.edu/abs/2003MNRAS.340..191R
* SN1999aw - http://adsabs.harvard.edu/abs/2002AJ....124.2905S
* SN1999by - http://adsabs.harvard.edu/abs/2002ApJ...568..791H
* SN1999el - http://adsabs.harvard.edu/abs/2002ApJ...573..144D
* SN1999em - http://adsabs.harvard.edu/abs/2003MNRAS.338..939E
* SN2000cx - http://adsabs.harvard.edu/abs/2002ApJ...565..413R
* SN2000ew - http://adsabs.harvard.edu/abs/2002PASJ...54..905G
* SN2001el - http://adsabs.harvard.edu/abs/2005A%26A...443..649M
* SN2002fk - http://adsabs.harvard.edu/abs/2014ApJ...789...89C
* SN2003hx - http://adsabs.harvard.edu/abs/2008MNRAS.389..706M
* SN2003ma - http://adsabs.harvard.edu/abs/2011ApJ...729...88R
* SN2004dj - http://adsabs.harvard.edu/abs/2011A%26A...527A..61S
* SN2004et - http://adsabs.harvard.edu/abs/2007MNRAS.381..280M, http://adsabs.harvard.edu/abs/2009ApJ...704..306K
* SN2005am - http://adsabs.harvard.edu/abs/2005ApJ...635.1192B
* SN2005df - http://adsabs.harvard.edu/abs/2015ApJ...806..107D
* SN2005ke - http://adsabs.harvard.edu/abs/2014A%26A...572A..75K
* SN2005hk - http://adsabs.harvard.edu/abs/2008ApJ...680..580S
* SN2006bc - http://adsabs.harvard.edu/abs/2012ApJ...753..109G
* SN2006gz - http://adsabs.harvard.edu/abs/2009ApJ...690.1745M
* SN2007ax - http://adsabs.harvard.edu/abs/2008ApJ...683L..29K
* SN2007gr - http://adsabs.harvard.edu/abs/2009A%26A...508..371H, http://adsabs.harvard.edu/abs/2010MNRAS.408...87M, http://adsabs.harvard.edu/abs/2014ApJ...790..120C
* SN2007od - http://adsabs.harvard.edu/abs/2012MNRAS.422.1178I
* SN2007pk - http://adsabs.harvard.edu/abs/2012ApJ...750..128P
* SN2007qd - http://adsabs.harvard.edu/abs/2010ApJ...720..704M
* SN2007if - http://adsabs.harvard.edu/abs/2010ApJ...715.1338Y
* SN2007it - http://adsabs.harvard.edu/abs/2011ApJ...731...47A
* SN2007ru - http://adsabs.harvard.edu/abs/2009ApJ...697..676S
* SN2007uy - http://adsabs.harvard.edu/abs/2013MNRAS.434.2032R
* SN2008D - http://www.nature.com/nature/journal/v453/n7194/suppinfo/nature06997.html
* SN2008fz - http://adsabs.harvard.edu/abs/2010ApJ...718L.127D
* SN2008ge - http://adsabs.harvard.edu/abs/2010AJ....140.1321F
* SN2008in - http://adsabs.harvard.edu/abs/2011ApJ...736...76R
* SN2009N - http://adsabs.harvard.edu/abs/2014MNRAS.438..368T
* SN2009bw - http://adsabs.harvard.edu/abs/2012MNRAS.422.1122I
* SN2009dc - http://adsabs.harvard.edu/abs/2009ApJ...707L.118Y
* SN2009ib - http://adsabs.harvard.edu/abs/2015MNRAS.450.3137T
* SN2009hd - http://adsabs.harvard.edu/abs/2011ApJ...742....6E
* SN2009ig - http://adsabs.harvard.edu/abs/2012ApJ...744...38F, http://adsabs.harvard.edu/abs/2013ApJ...777...40M
* SN2009ip - http://mnras.oxfordjournals.org/content/453/4/3886.full
* SN2009jf - http://adsabs.harvard.edu/abs/2011MNRAS.413.2583S
* SN2009kf - http://adsabs.harvard.edu/abs/2010ApJ...717L..52B
* SN2009kn - http://adsabs.harvard.edu/abs/2012MNRAS.424..855K
* SN2009kr - http://adsabs.harvard.edu/abs/2010ApJ...714L.280F
* SN2009ku - http://adsabs.harvard.edu/abs/2011ApJ...731L..11N
* SN2009nr - http://adsabs.harvard.edu/abs/2011ApJ...726..106K
* SN2010aq - http://adsabs.harvard.edu/abs/2010ApJ...720L..77G
* SN2010bh - http://iopscience.iop.org/article/10.1088/0004-637X/740/1/41/meta
* SN2010ev - http://adsabs.harvard.edu/abs/2016arXiv160107863G
* SN2010jl - http://adsabs.harvard.edu/abs/2014ApJ...797..118F, http://adsabs.harvard.edu/abs/2014ApJ...781...42O
* SN2010mb - http://adsabs.harvard.edu/abs/2014ApJ...785...37B
* SN2010X - http://adsabs.harvard.edu/abs/2010ApJ...723L..98K
* PS1-10afx - http://adsabs.harvard.edu/abs/2013ApJ...767..162C
* PS1-10bzj - http://adsabs.harvard.edu/abs/2013ApJ...771...97L
* SN2011ay - http://adsabs.harvard.edu/abs/2015MNRAS.453.2103S
* SN2011dh - http://adsabs.harvard.edu/abs/2013MNRAS.433....2S, http://adsabs.harvard.edu/abs/2014ApJ...781...69M
* SN2011fe - http://adsabs.harvard.edu/abs/2013ApJ...762L...5S, http://adsabs.harvard.edu/abs/2013ApJ...767..119M
* SN2011ht - http://adsabs.harvard.edu/abs/2013MNRAS.431.2599M
* SN2011kl - http://adsabs.harvard.edu/abs/2015Natur.523..189G
* PTF11iqb - http://adsabs.harvard.edu/abs/2015MNRAS.449.1876S
* PS1-11ap - http://mnras.oxfordjournals.org/content/437/1/656.full (Missing spectra)
* SN2012ap - http://adsabs.harvard.edu/abs/2015RAA....15..225L
* SN2012au - http://adsabs.harvard.edu/abs/2013ApJ...770L..38M, http://adsabs.harvard.edu/abs/2013ApJ...772L..17T
* SN2012aw - http://adsabs.harvard.edu/abs/2013MNRAS.433.1871B, http://adsabs.harvard.edu/abs/2014ApJ...787..139D
* SN2012bz - http://www.aanda.org/articles/aa/full_html/2014/06/aa23387-14/aa23387-14.html
* SN2012dn - http://adsabs.harvard.edu/abs/2014MNRAS.443.1663C
* PTF12csy - http://iopscience.iop.org.oca.ucsc.edu/article/10.1088/0004-637X/811/1/52/meta
* SN2013ab - http://adsabs.harvard.edu/abs/2015MNRAS.450.2373B
* SN2013am - http://adsabs.harvard.edu/abs/2014ApJ...797....5Z
* SN2013cq - http://adsabs.harvard.edu/abs/2014A%26A...567A..29M
* SN2013cu - http://adsabs.harvard.edu/abs/2014Natur.509..471G
* SN2013df - http://adsabs.harvard.edu/abs/2014MNRAS.445.1647M, http://adsabs.harvard.edu/abs/2015ApJ...803...40B, http://adsabs.harvard.edu/abs/2015ApJ...807...35M
* SN2013ej - http://adsabs.harvard.edu/abs/2015arXiv150901721D, http://adsabs.harvard.edu/abs/2015ApJ...807...59H
* SN2013en - http://adsabs.harvard.edu/abs/2015MNRAS.452..838L
* SN2013hx - Inserra+ 2013 in prep.?
* PTF13efv (SNhunt275) - http://arxiv.org/abs/1605.02450
* iPTF13ajg - http://iopscience.iop.org/article/10.1088/0004-637X/797/1/24/meta
* iPTF13asv - http://adsabs.harvard.edu/abs/2016arXiv160100686C
* iPTF13ebh - http://www.aanda.org/articles/aa/full_html/2015/06/aa25297-14/aa25297-14.html (LC available but spread over several misformatted tables)
* SN2014J - http://adsabs.harvard.edu/abs/2014ApJ...795L...4K, http://adsabs.harvard.edu/abs/2014ApJ...784L..12G, http://adsabs.harvard.edu/abs/2015ApJ...804...66V, http://adsabs.harvard.edu/abs/2015ApJ...798...93T, http://adsabs.harvard.edu/abs/2015ApJ...798...39M, http://adsabs.harvard.edu/abs/2015MNRAS.451.4104J, http://adsabs.harvard.edu/abs/2016MNRAS.457.1000S
* SN2014C - http://adsabs.harvard.edu/abs/2015ApJ...815..120M  (LC & spectra, data not in paper)
* iPTF14atg - http://adsabs.harvard.edu/abs/2015Natur.521..328C (LC, data not in paper)
* SN2015H - http://adsabs.harvard.edu/abs/2016A%26A...589A..89M (LC, data not in paper)
* SN2015U - http://arxiv.org/abs/1603.04866
* SN2015bn - http://arxiv.org/abs/1603.04748
* iPTF15dtg - http://arxiv.org/abs/1605.02491

Spectra to recover that were donated to SuSpect (bad wavelength solutions, etc):
* 2000E_20000130_3274_7356_00.dat
* 2000E_20000131_3274_7349_00.dat
* 2000E_20000603_3257_6994_00.dat
* 2000E_20000604_3258_6926_00.dat
* 2000E_20000605_3258_7040_00.dat
* 2004aw_20040421_5227_22727_01.dat
* 2004aw_20040421_13915_24565_00.dat
* 2004dt_20040912_3600_9052_00.dat
* 2007C_20070620_3005_10406_00.dat
* 2008S_20080205_3129_8255_00.dat
* 2008S_20080211_4953_10052_00.dat
* 2008S_20080227_4841_10187_00.dat
* 2008S_20080304_3340_8981_00.dat
* 2008S_20080307_4796_9637_00.dat
* 2008S_20080401_3496_7532_00.dat
* 2008S_20080405_6109_6658_00.dat
* 2008S_20080519_5215_7984_00.dat
* 1986G_19860507_3403_5581_00.dat
* 1986G_19860507_3403_7176_00.dat
* 1986G_19870122_3600_9390_00.dat
* 1997br_19970508_3304_9979_00.dat
* 1997cn_19970616_3249_9646_00.dat
* 1992H_19920529_3739_9809_00.dat
* 1992H_19920623_4000_7570_00.dat
* 1992H_19920702_4000_7570_00.dat
* 1996X_19960613_2806_10203_00.dat
* 1996X_19960614_2806_9811_00.dat
* 1998A_19980124_3080_9501_00.dat
* 1998A_19980126_2994_10529_00.dat
* 1998A_19980218_2838_10359_00.dat
* 1998A_19980322_3085_8695_00.dat
* 1997cy_19970824_3211_10409_00.dat
* 1997cy_19971204_3200_8832_00.dat
* 1997cy_19980218_2851_10302_00.dat
* 1997cy_19980322_3032_8633_00.dat

SNR catalogs:
* Chandra SNR catalog - http://hea-www.cfa.harvard.edu/ChandraSNR/
* GALEX SNR catalog?
* GRBs (BATSE, Swift, FERMI). LGRBs are definitely SNe, should we considered SGRBs to be SNe?

Online catalogs:
* No known missing online catalogs at this time.

####Data that likely exists but no known source
* Any SNe with a typing but no spectrum likely has a spectrum.

####Known errors that need to be corrected:
* No known errors at this time.
